Learn R Programming

rdav (version 0.3.0)

ncl_shareurl: Builds the Nextcloud base URL for a public share from host and user names

Description

Builds the Nextcloud base URL for a public share from host and user names

Usage

ncl_shareurl(hostname, username, path_prefix = "")

Value

share url to use with wd_connect

Arguments

hostname

host name

username

user name

path_prefix

ptional path to webdav directory

Examples

Run this code
ncl_shareurl("example.com", "johndoe")

Run the code above in your browser using DataLab