Learn R Programming

rdav (version 0.3.0)

ncl_shareurl_from_publicurl: Creates the Nextcloud base URL for a share from a public share url

Description

Creates the Nextcloud base URL for a share from a public share url

Usage

ncl_shareurl_from_publicurl(url)

Value

share url to use with wd_connect

Arguments

url

link to public share

Examples

Run this code
ncl_shareurl_from_publicurl("https://example.com/s/87d7edad/")

Run the code above in your browser using DataLab