Learn R Programming

rdav (version 0.3.0)

ncl_username_from_url: Extracts the user name from a Nextcloud Base URL

Description

Extracts the user name from a Nextcloud Base URL

Usage

ncl_username_from_url(url)

Value

user name

Arguments

url

base or share url

Examples

Run this code
ncl_username_from_url("https://example.com/remote.php/dav/files/johndoe")

Run the code above in your browser using DataLab