Learn R Programming

rdav (version 0.3.0)

ocs_shares_extended: Returns information for shares

Description

ocs_shares_extended returns extended information for shares. ocs_shares returns the shares of a file or folder, ocs_child_shares the shares of the files and subfolders of the given path.

Usage

ocs_shares_extended(
  req,
  path = "",
  as_df = TRUE,
  columns = NULL,
  subfiles = TRUE,
  reshares = FALSE
)

ocs_child_shares( req, path = "", as_df = TRUE, columns = c("share_type", "item_type", "permissions", "label", "uid_owner", "share_with_displayname") )

ocs_shares( req, path = "/", as_df = TRUE, columns = c("share_type", "item_type", "permissions", "label", "uid_owner", "share_with_displayname") )

Value

data.frame or named vector of IDs

Arguments

req

WebDAV request as returned by wd_connect

path

folder or file path

as_df

if TRUE (default) a data.frame is returned, else a list of IDs

columns

column names that should be included into the result (default NULL includes all)

subfiles

list shares of subfolders

reshares

include shares from others

Examples

Run this code
if (FALSE) {
r <- wd_connect("https://example.com/remote.php/dav/files/johndoe")
ocs_shares_extended(r, "myfolder/shares")
ocs_shares(r, "myfolder/shares")
ocs_child_shares(r, "myfolder")
}

Run the code above in your browser using DataLab