wd_download: Fetches a file or directory (recursively) from the WebDAV server
Description
Directories are downloaded recursively.
If the source is a file and the target a directory, then the file is
downloaded to the target directory.
If the target is omitted, then the file or directory name
(basename) will be used.
Usage
wd_download(req, source, target = "")
Value
vector of downloaded files (invisibly)
Arguments
req
request handle obtained from wd_connect
source
path to source file or directory on server
target
path to local target file or directory, if omitted the file or
directory name will be used, if source is a file and target a directory
then the file will be put into the target directory